from quickforex.domain import CurrencyPair, DateRange
from quickforex.api import (
    Api,
    get_latest_rates,
    get_latest_rate,
    get_historical_rates,
    get_historical_rate,
    get_rates_time_series,
)


__version__ = "0.0.4"


__all__ = [
    "Api",
    "get_latest_rates",
    "get_latest_rate",
    "get_historical_rates",
    "get_historical_rate",
    "get_rates_time_series",
    "CurrencyPair",
    "DateRange",
]
